data "aws_sns_topic" "cloudmon" {
  name = "edebrye-cloudmon"
}

resource "aws_cloudwatch_metric_alarm" "lambda_throttles_alarm" {
  for_each = local.lambdas

  alarm_name          = "${local.prefix}-${each.key}-throttle-alarm"
  alarm_description   = "Alert staff when throttles occurs on cloud-monitor project's lambdas."
  comparison_operator = "GreaterThanOrEqualToThreshold"
  evaluation_periods  = 1
  period              = 300
  threshold           = 1
  namespace           = "AWS/Lambda"
  statistic           = "Sum"
  alarm_actions       = [data.aws_sns_topic.cloudmon.arn]
  ok_actions          = [data.aws_sns_topic.cloudmon.arn]
  metric_name         = "Throttles"

  dimensions = {
    FunctionName = aws_lambda_function.crud[each.key].function_name
  }
  tags = local.common_tags
}


resource "aws_cloudwatch_metric_alarm" "lambda_error_alarm" {
  for_each = local.lambdas

  alarm_name          = "${local.prefix}-${each.key}-error-alarm"
  alarm_description   = "Alert staff when errors occurs on cloud-monitor project's lambdas."
  comparison_operator = "GreaterThanOrEqualToThreshold"
  evaluation_periods  = 1
  period              = 300
  threshold           = 1
  namespace           = "AWS/Lambda"
  statistic           = "Sum"
  alarm_actions       = [data.aws_sns_topic.cloudmon.arn]
  ok_actions          = [data.aws_sns_topic.cloudmon.arn]
  metric_name         = "Errors"

  dimensions = {
    FunctionName = aws_lambda_function.crud[each.key].function_name
  }
  tags = local.common_tags
}